/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *   * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.wso2.registry.servlet;

import org.wso2.registry.*;
import org.wso2.registry.secure.SecureRegistry;
import org.wso2.usermanager.Realm;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.Map;

public class Utils {

    /**
     * Extract the paramters from the query string.
     * e.g. for the URL
     * http://localhost:8080/registry/d1/myresource?action=tag,tag_value=support project
     * we have the query string "action=tag,tag_value=support project"
     * it should be extracted to map as
     * key=action, value=tag
     * key=tag_value, value=support project
     *
     * @param queryString query string of the URL
     * @return Map containg paramter name --> paramter value pairs
     */
    public static Map getParameters(String queryString) {

        Map paramMap = new HashMap();

        String[] params = queryString.split(",");

        for (int i = 0; i < params.length; i++) {
            String[] param = params[i].split("=");
            paramMap.put(param[0].trim(), param[1].trim());
        }

        return paramMap;
    }

    /**
     * Returns the registry associated with the current session. If a user registry is not found,
     * new SecureRegistry instance is created with annoymous user and associated for the current
     * session.
     *
     * @param request Servlet request
     * @return SecureRegistry instance for the current session.
     */
    public static synchronized SecureRegistry getSecureRegistry(HttpServletRequest request)
            throws RegistryException {

        SecureRegistry registry;
        Object o = request.getSession().getAttribute(RegistryConstants.USER_REGISTRY);
        if (o != null) {
            registry = (SecureRegistry) o;
        } else {
            Registry coreRegistry = (Registry) request.
                    getSession().getServletContext().getAttribute(RegistryConstants.REGISTRY);

            Realm realm = (Realm) request.getSession().getServletContext().
                                        getAttribute(RegistryConstants.REGISTRY_REALM);

            registry = new SecureRegistry(
                    RegistryConstants.ANONYMOUS_USER, "guest", coreRegistry, realm);

            request.getSession().setAttribute(RegistryConstants.USER_REGISTRY, registry);
        }

        return registry;
    }

    public static synchronized void setSecureRegistry(
            HttpServletRequest request, SecureRegistry secureRegistry) {
        
        request.getSession().setAttribute(RegistryConstants.USER_REGISTRY, secureRegistry);
    }

    public static void populateDummyData(Registry JDBCRegistry) {
        try {
            // create a content resource
            Artifact resource1 = new Artifact();
            resource1.setAuthorUserName("Jonathan");
            String content1 = "This is content1";
            resource1.setContent(content1.getBytes());
            resource1.setDescription("Sudoku puzzle generator");
            // store it in a non existence path
            String path1 = "/mashups/sudoku";
            JDBCRegistry.put(path1, resource1);
            JDBCRegistry.addComment(path1, new Comment("I think this service would be even nicer if it had bells on it's toes. Anyone think I should add them?."));
            JDBCRegistry.addComment(path1, new Comment("I couldn't get the bar to foo correctly. Are your indices zero-based or 1-based?."));
            JDBCRegistry.applyTag(path1, "Game");
            JDBCRegistry.applyTag(path1, "puzzle");
            JDBCRegistry.applyTag(path1, "sudoku");
			
            Artifact resource2 = new Artifact();
            resource2.setAuthorUserName("Jonathan");
            String content2 = "This is content1";
            resource2.setContent(content2.getBytes());
            resource2.setDescription("Store named XML blobs");
            String path2 = "/mashups/storexml";
            JDBCRegistry.put(path2, resource2);
            JDBCRegistry.addComment(path2, new Comment("Please ignore the previous post. Don't know what I was testing!"));
            JDBCRegistry.addComment(path2, new Comment("this is a test"));
            JDBCRegistry.applyTag(path2, "storage");
            JDBCRegistry.applyTag(path2, "persistence");
            JDBCRegistry.applyTag(path2, "namevaluepairs");
			
            Artifact resource3 = new Artifact();
            resource3.setAuthorUserName("Jonathan");
            String content3 = "This is content1";
            resource3.setContent(content3.getBytes());
            resource3.setDescription("Sudoku puzzle generator");
            String path3 = "/mashups/sudoku2";
            JDBCRegistry.put(path3, resource3);

            // store another content resource in the same path
            Artifact resource4 = new Artifact();
            resource4.setAuthorUserName("Administrator");
            String content4 = "This is content2";
            resource4.setContent(content4.getBytes());
            resource4.setDescription("WSO2 Mashup Server version information service");
            String path4 = "/mashups/version";
            JDBCRegistry.put(path4, resource4);

            String sqlDes = "SELECT PATH FROM ARTIFACTS WHERE DESCRIPTION LIKE ?";
            Artifact searchDescription = new Artifact();
            searchDescription.setContent(sqlDes);
            searchDescription.setMediaType(RegistryConstants.SQL_QUERY_MEDIA_TYPE);
            searchDescription.setProperty(RegistryConstants.RESULT_TYPE_PROPERTY_NAME, RegistryConstants.RESOURCES_RESULT_TYPE);
            JDBCRegistry.put("/qs/searchDescription", searchDescription);

            String sqlTag = "SELECT PATH FROM ARTIFACTS WHERE TAGS LIKE ?";
            Artifact searchTag = new Artifact();
            searchTag.setContent(sqlTag);
            searchTag.setMediaType(RegistryConstants.SQL_QUERY_MEDIA_TYPE);
            searchTag.setProperty(RegistryConstants.RESULT_TYPE_PROPERTY_NAME, RegistryConstants.RESOURCES_RESULT_TYPE);
            JDBCRegistry.put("/qs/searchTag", searchTag);

            String sqlTitle = "SELECT PATH FROM ARTIFACTS WHERE PATH LIKE ?";
            Artifact searchName = new Artifact();
            searchName.setContent(sqlTitle);
            searchName.setMediaType(RegistryConstants.SQL_QUERY_MEDIA_TYPE);
            searchName.setProperty(RegistryConstants.RESULT_TYPE_PROPERTY_NAME, RegistryConstants.RESOURCES_RESULT_TYPE);
            JDBCRegistry.put("/qs/searchName", searchName);

            String sqlAuthor = "SELECT PATH FROM ARTIFACTS WHERE AUTHOR LIKE ?";
            Artifact searchUser = new Artifact();
            searchUser.setContent(sqlAuthor);
            searchUser.setMediaType(RegistryConstants.SQL_QUERY_MEDIA_TYPE);
            searchUser.setProperty(RegistryConstants.RESULT_TYPE_PROPERTY_NAME, RegistryConstants.RESOURCES_RESULT_TYPE);
            JDBCRegistry.put("/qs/searchUser", searchUser);

            // store the third resource in a path starting from previous path
            Artifact resource5 = new Artifact();
            resource5.setAuthorUserName("Ruwan");
            String content5 = "This is content3";
            resource5.setContent(content5.getBytes());

            String path5 = "/d1/d2/d3/thirdresource";
            JDBCRegistry.put(path5, resource5);

            // add some tags
            JDBCRegistry.applyTag(path1, "game");
            JDBCRegistry.applyTag(path1, "first resource to be tagged");
            JDBCRegistry.applyTag(path1, "test data");

            JDBCRegistry.applyTag(path2, "test data");
            JDBCRegistry.applyTag(path2, "another test");

            // add some comments
            Comment comment1 = new Comment();
            comment1.setCommentText("I like this one");
            JDBCRegistry.addComment(path1, comment1);

            Comment comment2 = new Comment();
            comment2.setCommentText("this looks like a test resource...");
            JDBCRegistry.addComment(path1, comment2);

            // rate some resources
            JDBCRegistry.rateResource(path1, 2);
            JDBCRegistry.rateResource(path1, 5);
			JDBCRegistry.rateResource(path2, 3);
			JDBCRegistry.rateResource(path3, 4);

            JDBCRegistry.rateResource(path4, 1);
            JDBCRegistry.rateResource(path4, 3);

        } catch (RegistryException e) {
            e.printStackTrace();
        }

    }
}
